@@ -25,6 +25,8 @@ output = ""
 exchange = None
 container_files_path = None
 
+container_version = "2"
+
 
 def deal_with_stdout():
     global process
@@ -84,8 +86,8 @@ async def callback(message: aio_pika.IncomingMessage):
                         break
                     await send_status(
                         message=json.dumps(c2profile),
-                        routing_key="c2.status.{}.{}.sync_classes.{}".format(
-                            hostname, "running" if running else "stopped", username
+                        routing_key="c2.status.{}.{}.sync_classes.{}.{}".format(
+                            hostname, "running" if running else "stopped", username, container_version
                         ),
                     )
                 except Exception as e:
@@ -93,8 +95,8 @@ async def callback(message: aio_pika.IncomingMessage):
                         message='{"message": "Error while syncing info: {}"}'.format(
                             str(traceback.format_exc())
                         ),
-                        routing_key="c2.status.{}.{}.sync_classes.{}".format(
-                            hostname, "running" if running else "stopped", username
+                        routing_key="c2.status.{}.{}.sync_classes.{}.{}".format(
+                            hostname, "running" if running else "stopped", username, container_version
                         ),
                     )
             else:
@@ -120,7 +122,8 @@ async def get_status(request):
     output_message = {
         "running": running,
         "output": output,
-        "status": "success"
+        "status": "success",
+        "version": container_version
     }
     output = ""
     return output_message
@@ -152,7 +155,8 @@ async def start_profile(request):
             output_message = {
                 "status": "success",
                 "running": running,
-                "output": "Failed to start\nOutput: {}".format(output)
+                "output": "Failed to start\nOutput: {}".format(output),
+                "version": container_version
 
             }
             output = ""
@@ -161,7 +165,8 @@ async def start_profile(request):
             output_message = {
                 "status": "success",
                 "running": running,
-                "output": "Started with pid: {}...\nOutput: {}".format(str(process.pid), output)
+                "output": "Started with pid: {}...\nOutput: {}".format(str(process.pid), output),
+                "version": container_version
 
             }
             output = ""
@@ -169,7 +174,8 @@ async def start_profile(request):
         output_message = {
             "status": "success",
             "running": running,
-            "output": "Already running...\nOutput: {}".format(output)
+            "output": "Already running...\nOutput: {}".format(output),
+            "version": container_version
         }
         output = ""
     return output_message
@@ -195,14 +201,16 @@ async def stop_profile(request):
         output_message = {
             "status": "success",
             "output": "Process killed...\nOld Output: {}".format(output),
-            "running": running
+            "running": running,
+            "version": container_version
         }
         output = ""
     else:
         output_message = {
             "status": "success",
             "running": running,
-            "output": "Process not running...\nOld Output: {}".format(output)
+            "output": "Process not running...\nOld Output: {}".format(output),
+            "version": container_version
         }
         output = ""
     return output_message
@@ -218,8 +226,8 @@ async def sync_classes():
             break
         await send_status(
             message=json.dumps(c2profile),
-            routing_key="c2.status.{}.{}.sync_classes.{}".format(
-                hostname, "running" if running else "stopped", ""
+            routing_key="c2.status.{}.{}.sync_classes.{}.{}".format(
+                hostname, "running" if running else "stopped", "", container_version
             ),
         )
     except Exception as e:
@@ -227,8 +235,8 @@ async def sync_classes():
             message='{"message": "Error while syncing info: {}"}'.format(
                 str(traceback.format_exc())
             ),
-            routing_key="c2.status.{}.{}.sync_classes.{}".format(
-                hostname, "running" if running else "stopped", ""
+            routing_key="c2.status.{}.{}.sync_classes.{}.{}".format(
+                hostname, "running" if running else "stopped", "", container_version
             ),
         )
 
@@ -246,6 +254,7 @@ async def get_file(request):
         "running": running,
         "filename": str(path),
         "data": base64.b64encode(file_data).decode("utf-8"),
+        "version": container_version
     }
 
 
@@ -259,22 +268,25 @@ async def write_file(request):
             response = {
                 "status": "error",
                 "error": "trying to break out of path",
-                "running": running
+                "running": running,
+                "version": container_version
             }
         else:
             file = open(file_path, "wb")
-            file.write(base64.b64decode(reqest["data"]))
+            file.write(base64.b64decode(request["data"]))
             file.close()
             response = {
                 "status": "success", 
                 "filename": str(file_path),
                 "running": running
+                "version": container_version
             }
     except Exception as e:
         response = {
             "status": "error", 
             "error": str(e),
-            "running": running
+            "running": running,
+            "version": container_version
         }
     return response
 
